*12345678901234567890123456789012345678901234567890123456789012345678901234567890
capture log close
clear all
set more off

*	************************************************************************
* 	File-Name: 	SurveyAnalsys.do
*	Log-file:	survey_analsysis_v1.log
*	Date:  		03/24/2012
*	Author: 	Michal Aklin (NYU) & Johannes Urpelainen (Columbia)
*	Data Used:  surveymessage_dataset.dta
*				
*	Purpose:   	Replication package for: Aklin, Michal and Johannes Urpelainen
*				(2013). "Debating clean energy: Frames, Counter Frames, and 
*				Audiences." Global Environmental Change, forthcoming.
*
*	Structure:	0. Directory
*				PART I: Original survey data
*					1. Coding do file
*					2. Analysis
*					3. Graphs
*				PART II: MTurk
*					1. Coding do file
*					2. Analysis
*					3. Graphs
*	************************************************************************


*	************************************************************************
* 	0. Directory
*		CHANGE DIRECTORY AS NEEDED. This is necessary for this do file
*		to work properly. The directory should be the folder in which
*		you downloaded the replication package. 
*	************************************************************************

cd ""


******************************************************************************
*	PART I. ORIGINAL DATA
******************************************************************************

*	************************************************************************
* 	1. Run the coding do file
*	************************************************************************

*	Running the do file
quiet do "SurveyCoding.do"

*	Survey data with weights
svyset _n [pweight = v102]
svydes

*	************************************************************************
* 	2. Analysis
*	************************************************************************


*	************************************************************************
* 	Table 1: Summary stats
*	************************************************************************


estpost svy: tabulate treatment1 cuc420_v2, row percent
esttab using "rtable1.tex",	///
	se nostar unstack varlabels(`e(labels)') eqlabels(`e(eqlabels)') replace ///
	addnote("This table reports the level of support by respondents for clean energy public policies." "Each cell shows the percentage of individuals giving a particular response among those that have received the same treatment" "(i.e. within a given row). For instance, 33.13\% of those who received the Econ+, Econ- treatment have indicated that they would" " 'strongly support' clean energy policies." "See the main text for the definition of the various treatments.") ///
	title(Support for Clean Energy Policy Distribution\label{rtable1})
eststo clear


*	************************************************************************
* 	Table 1
*		cuc420_v2: dependent variable (recoded from 0 to 4)
*		treatment1: treatment (combination of a positive and negative frame)
*			1 = Econ+Econ-
*			2 = Econ+Sec-
*			3 = Sec+Econ-
*			4 = Sec+Sec-
*	************************************************************************

*	1. Basic treatment case (Column 1)
svy: mean cuc420_v2, over(treatment1)

*	2. All differences in means and t-test
di [cuc420_v2]_subpop_1 - [cuc420_v2]_subpop_2
test [cuc420_v2]_subpop_1 = [cuc420_v2]_subpop_2

di [cuc420_v2]_subpop_1 - [cuc420_v2]_subpop_3
test [cuc420_v2]_subpop_1 = [cuc420_v2]_subpop_3

di [cuc420_v2]_subpop_1 - [cuc420_v2]_subpop_4
test [cuc420_v2]_subpop_1 = [cuc420_v2]_subpop_4

di [cuc420_v2]_subpop_2 - [cuc420_v2]_subpop_3
test [cuc420_v2]_subpop_2 = [cuc420_v2]_subpop_3

di [cuc420_v2]_subpop_2 - [cuc420_v2]_subpop_4
test [cuc420_v2]_subpop_2 = [cuc420_v2]_subpop_4

di [cuc420_v2]_subpop_3 - [cuc420_v2]_subpop_4
test [cuc420_v2]_subpop_3 = [cuc420_v2]_subpop_4



*	************************************************************************
* 	Table A2 Regression analysis
*	************************************************************************

preserve
eststo: reg cuc420_v2 treatdummy* [pweight = v102], noconst
eststo: reg cuc420_v2 treatdummy* income conservative religious educ globalwarming [pweight = v102], noconst
esttab using "rtable8.tex", replace r2 booktabs b(2) se(2) scalars("rmse $\hat{\sigma}$") label star(* 0.10 ** 0.05 *** 0.01) ///
mtitles("Model" "Model") title(Support for New Clean Energy Policy - OLS\label{rtable8}) ///
addnote("Estimates from a linear least square regression analysis estimated without a constant." "The outcome is the degree of support for a hypothetical new clean energy policy. The response is coded between 0 (strongly opposed) and 4 (strongly supports)." "\textit{Econ+}: [The new clean energy] policy could improve America's economy by creating new jobs." "\textit{Econ-}: [The new clean energy] policy could also weaken the economy by increasing energy prices." "\textit{Sec+}: [The new clean energy] policy could improve America's national security by reducing oil imports from the Middle East." "\textit{Sec-}: [The new clean energy] policy could also weaken national security by preventing the use of domestic coal resources.")
eststo clear
restore




******************************************************************************
*	3. Graphs
******************************************************************************

catplot cuc420_v2, by(treatment1) percent(treatment1) recast(bar) 	///
				scheme(s2mono) graphregion(fcolor(white)) var1opts(label(angle(45)))
graph export "graph1.pdf", replace as(pdf)


catplot cuc420_v2, by(treatment1) percent(treatment1)  	///
				scheme(s2mono) graphregion(fcolor(white)) var1opts(label(angle(45)))
graph export "graph2.pdf", replace as(pdf)








******************************************************************************
*	PART II. MTURK
******************************************************************************

******************************************************************************
*	1. Calling up the data
******************************************************************************

do "SurveyMTurkCoding.do"

svyset _n
svydes

******************************************************************************
*	2. Analysis
******************************************************************************

******************************************************************************
*	Summary Statistics
******************************************************************************

*	Replication of Table 1
estpost svy: tabulate treatment_gec gec_o1, row percent obs
esttab using "mturktable1.tex",	///
	se nostar unstack varlabels(`e(labels)') eqlabels(`e(eqlabels)') replace ///
	addnote("This table reports the level of support by respondents for clean energy public policies." "Each cell shows the percentage of individuals giving a particular response among those that have received the same treatment" "(i.e. within a given row). For instance, 33.13\% of those who received the Econ+, Econ- treatment have indicated that they would" " 'strongly support' clean energy policies." "See the main text for the definition of the various treatments.") ///
	title(Support to Clean Energy Policy Distribution - MTurk\label{mturktable1})
eststo clear


*	************************************************************************
* 	Table 2
*	************************************************************************

*	1. Basic treatment case
svy: mean gec_o1, over(treatment_gec)

*	2. MTurk Table 2 (Replication of Table 2). All t-test
* First row
di [gec_o1]_subpop_4 - [gec_o1]_subpop_3
test [gec_o1]_subpop_4 = [gec_o1]_subpop_3

di [gec_o1]_subpop_4 - [gec_o1]_subpop_2
test [gec_o1]_subpop_4 = [gec_o1]_subpop_2

di [gec_o1]_subpop_4 - [gec_o1]_subpop_1
test [gec_o1]_subpop_4 = [gec_o1]_subpop_1

* Second row
di [gec_o1]_subpop_3 - [gec_o1]_subpop_2
test [gec_o1]_subpop_3 = [gec_o1]_subpop_2

di [gec_o1]_subpop_3 - [gec_o1]_subpop_1
test [gec_o1]_subpop_3 = [gec_o1]_subpop_1

* Third row
di [gec_o1]_subpop_2 - [gec_o1]_subpop_1
test [gec_o1]_subpop_2 = [gec_o1]_subpop_1


*	3. TABLE 2B. 
*	Expectation: positive
di [gec_o1]_subpop_6 - [gec_o1]_subpop_1
test [gec_o1]_subpop_6 = [gec_o1]_subpop_1

*	Expectation: negative
di [gec_o1]_subpop_8 - [gec_o1]_subpop_1
test [gec_o1]_subpop_8 = [gec_o1]_subpop_1

*	Expectation: positive
di [gec_o1]_subpop_6 - [gec_o1]_subpop_2
test [gec_o1]_subpop_6 = [gec_o1]_subpop_2

*	Expectation: negative
di [gec_o1]_subpop_9 - [gec_o1]_subpop_2
test [gec_o1]_subpop_9 = [gec_o1]_subpop_2

*	Expectation: positive
di [gec_o1]_subpop_7 - [gec_o1]_subpop_3
test [gec_o1]_subpop_7 = [gec_o1]_subpop_3

*	Expectation: negative
di [gec_o1]_subpop_8 - [gec_o1]_subpop_3
test [gec_o1]_subpop_8 = [gec_o1]_subpop_3

*	Expectation: positive
di [gec_o1]_subpop_7 - [gec_o1]_subpop_4
test [gec_o1]_subpop_7 = [gec_o1]_subpop_4

*	Expectation: negative
di [gec_o1]_subpop_9 - [gec_o1]_subpop_4
test [gec_o1]_subpop_9 = [gec_o1]_subpop_4



*	************************************************************************
* 	Table A5 Regression analysis
*	************************************************************************

preserve
eststo: reg gec_o1 treat_gec*, noconst
eststo: reg gec_o1 treat_gec* income conservative religious educ globalwarming, noconst
esttab using "mturktable3.tex", replace r2 booktabs b(2) se(2) scalars("rmse $\hat{\sigma}$") label star(* 0.10 ** 0.05 *** 0.01) ///
mtitles("Model" "Model") title(MTurk - Support for New Clean Energy Policy - OLS\label{mturktable3}) ///
addnote("Estimates from a linear least square regression analysis estimated without a constant." "The outcome is the degree of support for a hypothetical new clean energy policy." "The response is coded between 0 (strongly opposed) and 4 (strongly supports)." "\textit{Econ+}: [The new clean energy] policy could improve America's economy by creating new jobs." "\textit{Econ-}: [The new clean energy] policy could also weaken the economy by increasing energy prices." "\textit{Sec+}: [The new clean energy] policy could improve America's national security by reducing oil imports from the Middle East." "\textit{Sec-}: [The new clean energy] policy could also weaken national security by preventing the use of domestic coal resources.")
eststo clear
restore


******************************************************************************
*	4. Graphs
******************************************************************************

catplot gec_o1, by(treatment_gec) percent(treatment_gec) recast(bar) 	///
				scheme(s2mono) graphregion(fcolor(white)) var1opts(label(angle(45)))
graph export "mturkgraph1.pdf", replace as(pdf)


catplot gec_o1, by(treatment_gec) percent(treatment_gec)  	///
				scheme(s2mono) graphregion(fcolor(white)) var1opts(label(angle(45)))
graph export "mturkgraph2.pdf", replace as(pdf)

