*12345678901234567890123456789012345678901234567890123456789012345678901234567890
capture log close
clear all
set more off

*	************************************************************************
* 	File-Name: 	SurveyAnalysisMTurkData.do
*	Log-file:	na
*	Date:  		02/15/2012
*	Author: 	Michal Aklin
*	Data Used:  AklinUrpelainenMTurkData.dta
*	Output		MTurkData.dta
*	Purpose:   	.do file for data manipulation of MTurk data
*	************************************************************************


*	************************************************************************
* 	0. Load the data
*	************************************************************************

*	Loading the data
use "AklinUrpelainenMTurkData.dta"


*	************************************************************************
* 	1. Renaming the data
*	************************************************************************

*	GEC treatment
rename q47 gec_t1
rename q48 gec_t2
rename q49 gec_t3
rename q50 gec_t4
rename q51 gec_t5
rename q52 gec_t6
rename q53 gec_t7
rename q54 gec_t8
rename q55 gec_t9


*	Demographic
rename q6 scientist_trusttxt
rename q5 ideologytxt
rename q7 religiontxt
rename q8 globalwarmingtxt
rename q9 educationtxt
rename q10 incometxt




*	************************************************************************
* 	2. Generating the treatment variable
*	************************************************************************


gen treatment_gec = .
replace treatment_gec = 1 if gec_t1 != ""
replace treatment_gec = 2 if gec_t2 != ""
replace treatment_gec = 3 if gec_t3 != ""
replace treatment_gec = 4 if gec_t4 != ""
replace treatment_gec = 5 if gec_t5 != ""
replace treatment_gec = 6 if gec_t6 != ""
replace treatment_gec = 7 if gec_t7 != ""
replace treatment_gec = 8 if gec_t8 != ""
replace treatment_gec = 9 if gec_t9 != ""

label define tgec 1 "Sec+, Sec-" 2 "Sec+, Econ-" 3 "Econ+, Sec-" 4 "Econ+, Econ-" 5 "Baseline" 6 "Sec+" 7 "Econ+" 8 "Sec-" 9 "Econ-", replace
label values treatment_gec tgec

tab treatment_gec, gen(treat_gec)
label variable treat_gec1 "Sec+, Sec-"
label variable treat_gec2 "Sec+, Econ-"
label variable treat_gec3 "Econ+, Sec-"
label variable treat_gec4 "Econ+, Econ-"
label variable treat_gec5 "Baseline"
label variable treat_gec6 "Sec+"
label variable treat_gec7 "Econ+"
label variable treat_gec8 "Sec-"
label variable treat_gec9 "Econ-"


*	************************************************************************
* 	2. Generating outcome variables
*	************************************************************************


*	GEC (matches the revised paper's coding that goes from oppsition to support)
gen gec_o1txt = gec_t1 + gec_t2 + gec_t3 + gec_t4 + gec_t5 + gec_t6 + gec_t7 + gec_t8 + gec_t9
gen gec_o1 = .
replace gec_o1 = 4 if gec_o1txt == "Strongly support"
replace gec_o1 = 3 if gec_o1txt == "Somewhat support"
replace gec_o1 = 2 if gec_o1txt == "Neutral"
replace gec_o1 = 1 if gec_o1txt == "Somewhat oppose"
replace gec_o1 = 0 if gec_o1txt == "Strongly oppose"

label define label_geco1 0 "Strongly oppose" 1 "Somewhat oppose" 2 "Neutral" 3 "Somewhat support" 4 "Strongly support", replace
label values gec_o1 label_geco1


*	************************************************************************
* 	3. Recoding the control variables
*		ATTENTION: the coding mimicks the main survey data variable names
*	************************************************************************

*	Scientific trust
gen scientist_trust = .
replace scientist_trust = 0 if scientist_trusttxt == "Strongly agree"
replace scientist_trust = 1 if scientist_trusttxt == "Agree"
replace scientist_trust = 2 if scientist_trusttxt == "Neither Agree nor Disagree"
replace scientist_trust = 3 if scientist_trusttxt == "Disagree"
replace scientist_trust = 4 if scientist_trusttxt == "Strongly Disagree"
label variable scientist_trust "Trust in Scientists"

*	Ideology
gen conservative = .
replace conservative = 0 if ideologytxt == "Very liberal" | ideologytxt == "Liberal"
replace conservative = 0.5 if ideologytxt == "Moderate"
replace conservative = 1 if ideologytxt == "Conservative" | ideologytxt == "Very conservative"
label variable conservative "Conservative"

*	Religion
gen religious = .
replace religious = 1 if religiontxt == "Very Important"
replace religious = 0 if religiontxt == "Important"
replace religious = 0 if religiontxt == "Not too important"
replace religious = 0 if religiontxt == "Not at all Important"
label variable religious "Religious"

gen religiousb = .
replace religiousb = 0 if religiontxt == "Not at all Important"
replace religiousb = 1 if religiontxt == "Not too important"
replace religiousb = 2 if religiontxt == "Important"
replace religiousb = 3 if religiontxt == "Very Important"
label variable religiousb "Religious"

*	Global warming and international community
gen globalwarming = .
replace globalwarming = 0 if globalwarmingtxt == "Too Little"
replace globalwarming = 0 if globalwarmingtxt == "About right"
replace globalwarming = 1 if globalwarmingtxt == "Too much"
label variable globalwarming "Global Warming"

gen globalwarmingb = .
replace globalwarmingb = 0 if globalwarmingtxt == "Too Little"
replace globalwarmingb = 1 if globalwarmingtxt == "About right"
replace globalwarmingb = 2 if globalwarmingtxt == "Too much"
label variable globalwarmingb "Global Warming"


*	Education
gen educ = .
replace educ = 0 if educationtxt == "Did not graduate from high school" | educationtxt == "High school graduate"
replace educ = 1 if educationtxt == "Some college, but no degree (yet)" | educationtxt == "2-year college degree" | educationtxt == "4-year college degree" | educationtxt == "Postgraduate degree (MA, MBA, MD, JD, PhD, etc.)"
label variable educ "Education"
 
gen educationb = .
replace educationb = 0 if educationtxt == "Did not graduate from high school"
replace educationb = 1 if educationtxt == "High school graduate"
replace educationb = 2 if educationtxt == "Some college, but no degree (yet)"
replace educationb = 3 if educationtxt == "2-year college degree"
replace educationb = 4 if educationtxt == "4-year college degree"
replace educationb = 5 if educationtxt == "Postgraduate degree (MA, MBA, MD, JD, PhD, etc.)"
label variable educationb "Education"


*	Income
gen income = .
replace income = 0 if incometxt == "Less than $20,000"
replace income = 1 if incometxt == "$20,000-34,999"
replace income = 2 if incometxt == "$35,000-$49-999"
replace income = 3 if incometxt == "$50,000-$64,999"
replace income = 4 if incometxt == "$65,000-$79,999"
replace income = 5 if incometxt == "$80,000-$99,999"
replace income = 6 if incometxt == "$100,000-$119,999"
replace income = 7 if incometxt == "$120,000-$149,999"
replace income = 8 if incometxt == "$150,000 or more"
replace income = . if incometxt == "Prefer not to say"
label variable income "Income"


*	************************************************************************
* 	Saving the data
*	************************************************************************

save "MTurkData.dta", replace


